%% getData
%   resturn individual properties to calling function
% inputs:
%   object:Data - current object
% outputs:
%   grid0:Grid - Results Grid
%   grid1:Grid - Left Grid
%   grid2:Grid - Top Grid
%   name:string - Function name
%   inputs:string - input string
%   checked:boolean - typecheck status
% Author: Colin Eles elesc@mcmaster.ca
% Organization: McMaster Centre for Software Certification
function [grid0, grid1, grid2, name, inputs, checked, multi] = getData(object)
grid0 = object.Grid0;
grid1 = object.Grid1;
grid2 = object.Grid2;
name = object.function_name;
inputs = object.function_inputs;
checked = object.checked;
multi = object.multi_mode;
end

